# successor ![tests](https://github.com/microprediction/successor/workflows/tests/badge.svg) ![tests-38](https://github.com/microprediction/successor/workflows/tests-38/badge.svg) ![tests-37](https://github.com/microprediction/successor/workflows/tests-37/badge.svg) ![pypi](https://github.com/microprediction/successor/workflows/deploy-pypi/badge.svg)

Uses pre-trained tensorflow models to predict the next number in a sequence (or the next k)

